You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@weex.apache.org by cx...@apache.org on 2017/03/02 03:28:51 UTC

[17/25] incubator-weex git commit: * [android] fix the gap to margin

* [android]  fix the gap to margin


Project: http://git-wip-us.apache.org/repos/asf/incubator-weex/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-weex/commit/c6db620e
Tree: http://git-wip-us.apache.org/repos/asf/incubator-weex/tree/c6db620e
Diff: http://git-wip-us.apache.org/repos/asf/incubator-weex/diff/c6db620e

Branch: refs/heads/0.11-dev-recycler
Commit: c6db620e47dd4824a9b12449ecdb5c93345f0a80
Parents: 5069898
Author: zshshr <zh...@gmail.com>
Authored: Sun Feb 26 15:55:59 2017 +0800
Committer: zshshr <zh...@gmail.com>
Committed: Sun Feb 26 15:55:59 2017 +0800

----------------------------------------------------------------------
 .../taobao/weex/dom/WXRecyclerDomObject.java    |  38 +++-
 .../ui/component/list/BasicListComponent.java   |   7 +-
 .../weex/ui/component/list/WXListComponent.java |  48 +++-
 .../weex/ui/view/listview/WXRecyclerView.java   |   3 +-
 .../ui/view/listview/WXSpaceItemDecoration.java |   6 +-
 .../listview/WXStaggeredGridLayoutManager.java  | 218 +++++++++++++++++++
 6 files changed, 295 insertions(+), 25 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/c6db620e/android/sdk/src/main/java/com/taobao/weex/dom/WXRecyclerDomObject.java
----------------------------------------------------------------------
diff --git a/android/sdk/src/main/java/com/taobao/weex/dom/WXRecyclerDomObject.java b/android/sdk/src/main/java/com/taobao/weex/dom/WXRecyclerDomObject.java
index 61fda35..3ffaee4 100644
--- a/android/sdk/src/main/java/com/taobao/weex/dom/WXRecyclerDomObject.java
+++ b/android/sdk/src/main/java/com/taobao/weex/dom/WXRecyclerDomObject.java
@@ -284,22 +284,44 @@ public class WXRecyclerDomObject extends WXDomObject{
         }
     }
 
+    public void updateRecyclerAttr(){
+        preCalculateCellWidth();
+        int count = getChildCount();
+        for(int i=0;i<count; i++){
+            WXDomObject domObject = getChild(i);
+            if(WXBasicComponentType.CELL.equals(domObject.getType())) {
+                getChild(i).getStyles().put(Constants.Name.WIDTH, mColumnWidth);
+            }
+        }
+    }
+
     @Override
     public void updateAttr(Map<String, Object> attrs) {
         super.updateAttr(attrs);
         if(attrs.containsKey(Constants.Name.COLUMN_COUNT)
                 || attrs.containsKey(Constants.Name.COLUMN_GAP)
                 || attrs.containsKey(Constants.Name.COLUMN_WIDTH)){
-            preCalculateCellWidth();
+            updateRecyclerAttr();
+        }
+    }
 
-            int count = getChildCount();
-            for(int i=0;i<count; i++){
-                WXDomObject domObject = getChild(i);
-                if(WXBasicComponentType.CELL.equals(domObject.getType())) {
-                    getChild(i).getStyles().put(Constants.Name.WIDTH, mColumnWidth);
-                }
-            }
+    @Override
+    public void updateStyle(Map<String, Object> styles) {
+        super.updateStyle(styles);
+        if(styles.containsKey(Constants.Name.PADDING)
+                ||styles.containsKey(Constants.Name.PADDING_LEFT)
+                || styles.containsKey(Constants.Name.PADDING_RIGHT)){
+            preCalculateCellWidth();
+        }
+    }
 
+    @Override
+    public void updateStyle(Map<String, Object> styles, boolean byPesudo) {
+        super.updateStyle(styles, byPesudo);
+        if(styles.containsKey(Constants.Name.PADDING)
+                ||styles.containsKey(Constants.Name.PADDING_LEFT)
+                || styles.containsKey(Constants.Name.PADDING_RIGHT)){
+            preCalculateCellWidth();
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/c6db620e/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
----------------------------------------------------------------------
diff --git a/android/sdk/src/main/java/com/taobao/weex/ui/component/list/WXListComponent.java b/android/sdk/src/main/java/com/taobao/weex/ui/component/list/WXListComponent.java
index 9828d70..b8c0a31 100755
--- a/android/sdk/src/main/java/com/taobao/weex/ui/component/list/WXListComponent.java
+++ b/android/sdk/src/main/java/com/taobao/weex/ui/component/list/WXListComponent.java
@@ -211,6 +211,7 @@ import com.taobao.weex.annotation.Component;
 import com.taobao.weex.common.Constants;
 import com.taobao.weex.dom.WXDomObject;
 import com.taobao.weex.dom.WXRecyclerDomObject;
+import com.taobao.weex.dom.flex.Spacing;
 import com.taobao.weex.ui.component.WXBaseRefresh;
 import com.taobao.weex.ui.component.WXBasicComponentType;
 import com.taobao.weex.ui.component.WXComponent;
@@ -223,6 +224,8 @@ import com.taobao.weex.ui.view.listview.adapter.ListBaseViewHolder;
 import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
 import com.taobao.weex.utils.WXLogUtils;
 
+import java.util.Map;
+
 /**
  * Unlike other components, there is immutable bi-directional association between View and
  * ViewHolder, while only mutable and temporal uni-directional association between view and
@@ -235,6 +238,8 @@ import com.taobao.weex.utils.WXLogUtils;
 public class WXListComponent extends BasicListComponent<BounceRecyclerView> {
   private String TAG = "WXListComponent";
   private WXRecyclerDomObject mDomObject;
+  private float mPaddingLeft;
+  private float mPaddingRight;
 
   @Deprecated
   public WXListComponent(WXSDKInstance instance, WXDomObject dom, WXVContainer parent, String instanceId, boolean isLazy) {
@@ -253,9 +258,7 @@ public class WXListComponent extends BasicListComponent<BounceRecyclerView> {
       }else{
         mLayoutType = mDomObject.getLayoutType();
       }
-
-      mColumnCount = mDomObject.getColumnCount();
-      mColumnGap = mDomObject.getColumnGap();
+      updateRecyclerAttr();
 
     }
   }
@@ -308,40 +311,65 @@ public class WXListComponent extends BasicListComponent<BounceRecyclerView> {
       }, 100);
       return true;
     }
-
     return false;
   }
 
+  private void updateRecyclerAttr(){
+    mColumnCount = mDomObject.getColumnCount();
+    mColumnGap = mDomObject.getColumnGap();
+    mColumnWidth = mDomObject.getColumnWidth();
+    mPaddingLeft =mDomObject.getPadding().get(Spacing.LEFT);
+    mPaddingRight =mDomObject.getPadding().get(Spacing.RIGHT);
+  }
+
   @WXComponentProp(name = Constants.Name.COLUMN_WIDTH)
   public void setColumnWidth(int columnCount)  {
     if(mDomObject.getColumnWidth() != mColumnWidth){
+      markComponentUsable();
+      updateRecyclerAttr();
       WXRecyclerView wxRecyclerView = getHostView().getInnerView();
       wxRecyclerView.initView(getContext(), mLayoutType,mColumnCount,mColumnGap,getOrientation());
-      mColumnCount = mDomObject.getColumnCount();
     }
   }
 
   @WXComponentProp(name = Constants.Name.COLUMN_COUNT)
   public void setColumnCount(int columnCount){
-
     if(mDomObject.getColumnCount() != mColumnCount){
-      mColumnCount = mDomObject.getColumnCount();
+      markComponentUsable();
+      updateRecyclerAttr();
       WXRecyclerView wxRecyclerView = getHostView().getInnerView();
       wxRecyclerView.initView(getContext(), mLayoutType,mColumnCount,mColumnGap,getOrientation());
-
     }
-
   }
 
   @WXComponentProp(name = Constants.Name.COLUMN_GAP)
   public void setColumnGap(float columnGap) throws InterruptedException {
     if(mDomObject.getColumnGap() != mColumnGap) {
-      mColumnGap = mDomObject.getColumnGap();
+      markComponentUsable();
+      updateRecyclerAttr();
       WXRecyclerView wxRecyclerView = getHostView().getInnerView();
       wxRecyclerView.initView(getContext(), mLayoutType, mColumnCount, mColumnGap, getOrientation());
     }
   }
 
+  @Override
+  public void updateProperties(Map<String, Object> props) {
+    super.updateProperties(props);
+    if(props.containsKey(Constants.Name.PADDING)
+            ||props.containsKey(Constants.Name.PADDING_LEFT)
+            || props.containsKey(Constants.Name.PADDING_RIGHT)){
+
+      if(mPaddingLeft !=mDomObject.getPadding().get(Spacing.LEFT)
+              || mPaddingRight !=mDomObject.getPadding().get(Spacing.RIGHT)) {
+
+        markComponentUsable();
+        updateRecyclerAttr();
+        WXRecyclerView wxRecyclerView = getHostView().getInnerView();
+        wxRecyclerView.initView(getContext(), mLayoutType, mColumnCount, mColumnGap, getOrientation());
+      }
+    }
+
+  }
 
   @Override
   public void createChildViewAt(int index) {

http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/c6db620e/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXRecyclerView.java
----------------------------------------------------------------------
diff --git a/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXRecyclerView.java b/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXRecyclerView.java
index e46fbe0..adffd9b 100755
--- a/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXRecyclerView.java
+++ b/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXRecyclerView.java
@@ -211,7 +211,6 @@ import android.support.annotation.Nullable;
 import android.support.v7.widget.GridLayoutManager;
 import android.support.v7.widget.OrientationHelper;
 import android.support.v7.widget.RecyclerView;
-import android.support.v7.widget.StaggeredGridLayoutManager;
 import android.view.MotionEvent;
 
 import com.taobao.weex.common.Constants;
@@ -259,7 +258,7 @@ public class WXRecyclerView extends RecyclerView implements WXGestureObservable
     if (type == TYPE_GRID_LAYOUT) {
       setLayoutManager(new GridLayoutManager(context, columnCount,orientation,false));
     } else if (type == TYPE_STAGGERED_GRID_LAYOUT) {
-      setLayoutManager(new StaggeredGridLayoutManager(columnCount, orientation));
+      setLayoutManager(new WXStaggeredGridLayoutManager(columnCount, orientation));
       addItemDecoration(new WXSpaceItemDecoration(columnCount,columnGap));
 
     } else if (type == TYPE_LINEAR_LAYOUT) {

http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/c6db620e/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXSpaceItemDecoration.java
----------------------------------------------------------------------
diff --git a/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXSpaceItemDecoration.java b/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXSpaceItemDecoration.java
index c067c1a..dd9015c 100644
--- a/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXSpaceItemDecoration.java
+++ b/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXSpaceItemDecoration.java
@@ -211,8 +211,6 @@ import android.support.v7.widget.RecyclerView;
 import android.support.v7.widget.StaggeredGridLayoutManager;
 import android.view.View;
 
-import com.taobao.weex.utils.WXLogUtils;
-
 /**
  * Created by zhengshihan on 2017/2/20.
  */
@@ -244,11 +242,11 @@ public class WXSpaceItemDecoration extends RecyclerView.ItemDecoration {
 
             int margin = (int) (mColumnGap / mColumnCount);
             if(spanIndex % mColumnCount == 1){
+                layoutParams.setMarginStart(0);
                 layoutParams.setMarginEnd(margin);
-
             }else if (spanIndex % mColumnCount ==0){
                 layoutParams.setMarginStart(margin);
-
+                layoutParams.setMarginEnd(0);
             } else {
                 layoutParams.setMarginEnd(margin);
                 layoutParams.setMarginStart(margin);

http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/c6db620e/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXStaggeredGridLayoutManager.java
----------------------------------------------------------------------
diff --git a/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXStaggeredGridLayoutManager.java b/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXStaggeredGridLayoutManager.java
new file mode 100644
index 0000000..6bbb78e
--- /dev/null
+++ b/android/sdk/src/main/java/com/taobao/weex/ui/view/listview/WXStaggeredGridLayoutManager.java
@@ -0,0 +1,218 @@
+/**
+ *
+ *                                  Apache License
+ *                            Version 2.0, January 2004
+ *                         http://www.apache.org/licenses/
+ *
+ *    TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION
+ *
+ *    1. Definitions.
+ *
+ *       "License" shall mean the terms and conditions for use, reproduction,
+ *       and distribution as defined by Sections 1 through 9 of this document.
+ *
+ *       "Licensor" shall mean the copyright owner or entity authorized by
+ *       the copyright owner that is granting the License.
+ *
+ *       "Legal Entity" shall mean the union of the acting entity and all
+ *       other entities that control, are controlled by, or are under common
+ *       control with that entity. For the purposes of this definition,
+ *       "control" means (i) the power, direct or indirect, to cause the
+ *       direction or management of such entity, whether by contract or
+ *       otherwise, or (ii) ownership of fifty percent (50%) or more of the
+ *       outstanding shares, or (iii) beneficial ownership of such entity.
+ *
+ *       "You" (or "Your") shall mean an individual or Legal Entity
+ *       exercising permissions granted by this License.
+ *
+ *       "Source" form shall mean the preferred form for making modifications,
+ *       including but not limited to software source code, documentation
+ *       source, and configuration files.
+ *
+ *       "Object" form shall mean any form resulting from mechanical
+ *       transformation or translation of a Source form, including but
+ *       not limited to compiled object code, generated documentation,
+ *       and conversions to other media types.
+ *
+ *       "Work" shall mean the work of authorship, whether in Source or
+ *       Object form, made available under the License, as indicated by a
+ *       copyright notice that is included in or attached to the work
+ *       (an example is provided in the Appendix below).
+ *
+ *       "Derivative Works" shall mean any work, whether in Source or Object
+ *       form, that is based on (or derived from) the Work and for which the
+ *       editorial revisions, annotations, elaborations, or other modifications
+ *       represent, as a whole, an original work of authorship. For the purposes
+ *       of this License, Derivative Works shall not include works that remain
+ *       separable from, or merely link (or bind by name) to the interfaces of,
+ *       the Work and Derivative Works thereof.
+ *
+ *       "Contribution" shall mean any work of authorship, including
+ *       the original version of the Work and any modifications or additions
+ *       to that Work or Derivative Works thereof, that is intentionally
+ *       submitted to Licensor for inclusion in the Work by the copyright owner
+ *       or by an individual or Legal Entity authorized to submit on behalf of
+ *       the copyright owner. For the purposes of this definition, "submitted"
+ *       means any form of electronic, verbal, or written communication sent
+ *       to the Licensor or its representatives, including but not limited to
+ *       communication on electronic mailing lists, source code control systems,
+ *       and issue tracking systems that are managed by, or on behalf of, the
+ *       Licensor for the purpose of discussing and improving the Work, but
+ *       excluding communication that is conspicuously marked or otherwise
+ *       designated in writing by the copyright owner as "Not a Contribution."
+ *
+ *       "Contributor" shall mean Licensor and any individual or Legal Entity
+ *       on behalf of whom a Contribution has been received by Licensor and
+ *       subsequently incorporated within the Work.
+ *
+ *    2. Grant of Copyright License. Subject to the terms and conditions of
+ *       this License, each Contributor hereby grants to You a perpetual,
+ *       worldwide, non-exclusive, no-charge, royalty-free, irrevocable
+ *       copyright license to reproduce, prepare Derivative Works of,
+ *       publicly display, publicly perform, sublicense, and distribute the
+ *       Work and such Derivative Works in Source or Object form.
+ *
+ *    3. Grant of Patent License. Subject to the terms and conditions of
+ *       this License, each Contributor hereby grants to You a perpetual,
+ *       worldwide, non-exclusive, no-charge, royalty-free, irrevocable
+ *       (except as stated in this section) patent license to make, have made,
+ *       use, offer to sell, sell, import, and otherwise transfer the Work,
+ *       where such license applies only to those patent claims licensable
+ *       by such Contributor that are necessarily infringed by their
+ *       Contribution(s) alone or by combination of their Contribution(s)
+ *       with the Work to which such Contribution(s) was submitted. If You
+ *       institute patent litigation against any entity (including a
+ *       cross-claim or counterclaim in a lawsuit) alleging that the Work
+ *       or a Contribution incorporated within the Work constitutes direct
+ *       or contributory patent infringement, then any patent licenses
+ *       granted to You under this License for that Work shall terminate
+ *       as of the date such litigation is filed.
+ *
+ *    4. Redistribution. You may reproduce and distribute copies of the
+ *       Work or Derivative Works thereof in any medium, with or without
+ *       modifications, and in Source or Object form, provided that You
+ *       meet the following conditions:
+ *
+ *       (a) You must give any other recipients of the Work or
+ *           Derivative Works a copy of this License; and
+ *
+ *       (b) You must cause any modified files to carry prominent notices
+ *           stating that You changed the files; and
+ *
+ *       (c) You must retain, in the Source form of any Derivative Works
+ *           that You distribute, all copyright, patent, trademark, and
+ *           attribution notices from the Source form of the Work,
+ *           excluding those notices that do not pertain to any part of
+ *           the Derivative Works; and
+ *
+ *       (d) If the Work includes a "NOTICE" text file as part of its
+ *           distribution, then any Derivative Works that You distribute must
+ *           include a readable copy of the attribution notices contained
+ *           within such NOTICE file, excluding those notices that do not
+ *           pertain to any part of the Derivative Works, in at least one
+ *           of the following places: within a NOTICE text file distributed
+ *           as part of the Derivative Works; within the Source form or
+ *           documentation, if provided along with the Derivative Works; or,
+ *           within a display generated by the Derivative Works, if and
+ *           wherever such third-party notices normally appear. The contents
+ *           of the NOTICE file are for informational purposes only and
+ *           do not modify the License. You may add Your own attribution
+ *           notices within Derivative Works that You distribute, alongside
+ *           or as an addendum to the NOTICE text from the Work, provided
+ *           that such additional attribution notices cannot be construed
+ *           as modifying the License.
+ *
+ *       You may add Your own copyright statement to Your modifications and
+ *       may provide additional or different license terms and conditions
+ *       for use, reproduction, or distribution of Your modifications, or
+ *       for any such Derivative Works as a whole, provided Your use,
+ *       reproduction, and distribution of the Work otherwise complies with
+ *       the conditions stated in this License.
+ *
+ *    5. Submission of Contributions. Unless You explicitly state otherwise,
+ *       any Contribution intentionally submitted for inclusion in the Work
+ *       by You to the Licensor shall be under the terms and conditions of
+ *       this License, without any additional terms or conditions.
+ *       Notwithstanding the above, nothing herein shall supersede or modify
+ *       the terms of any separate license agreement you may have executed
+ *       with Licensor regarding such Contributions.
+ *
+ *    6. Trademarks. This License does not grant permission to use the trade
+ *       names, trademarks, service marks, or product names of the Licensor,
+ *       except as required for reasonable and customary use in describing the
+ *       origin of the Work and reproducing the content of the NOTICE file.
+ *
+ *    7. Disclaimer of Warranty. Unless required by applicable law or
+ *       agreed to in writing, Licensor provides the Work (and each
+ *       Contributor provides its Contributions) on an "AS IS" BASIS,
+ *       WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+ *       implied, including, without limitation, any warranties or conditions
+ *       of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
+ *       PARTICULAR PURPOSE. You are solely responsible for determining the
+ *       appropriateness of using or redistributing the Work and assume any
+ *       risks associated with Your exercise of permissions under this License.
+ *
+ *    8. Limitation of Liability. In no event and under no legal theory,
+ *       whether in tort (including negligence), contract, or otherwise,
+ *       unless required by applicable law (such as deliberate and grossly
+ *       negligent acts) or agreed to in writing, shall any Contributor be
+ *       liable to You for damages, including any direct, indirect, special,
+ *       incidental, or consequential damages of any character arising as a
+ *       result of this License or out of the use or inability to use the
+ *       Work (including but not limited to damages for loss of goodwill,
+ *       work stoppage, computer failure or malfunction, or any and all
+ *       other commercial damages or losses), even if such Contributor
+ *       has been advised of the possibility of such damages.
+ *
+ *    9. Accepting Warranty or Additional Liability. While redistributing
+ *       the Work or Derivative Works thereof, You may choose to offer,
+ *       and charge a fee for, acceptance of support, warranty, indemnity,
+ *       or other liability obligations and/or rights consistent with this
+ *       License. However, in accepting such obligations, You may act only
+ *       on Your own behalf and on Your sole responsibility, not on behalf
+ *       of any other Contributor, and only if You agree to indemnify,
+ *       defend, and hold each Contributor harmless for any liability
+ *       incurred by, or claims asserted against, such Contributor by reason
+ *       of your accepting any such warranty or additional liability.
+ *
+ *    END OF TERMS AND CONDITIONS
+ *
+ *    APPENDIX: How to apply the Apache License to your work.
+ *
+ *       To apply the Apache License to your work, attach the following
+ *       boilerplate notice, with the fields enclosed by brackets "[]"
+ *       replaced with your own identifying information. (Don't include
+ *       the brackets!)  The text should be enclosed in the appropriate
+ *       comment syntax for the file format. We also recommend that a
+ *       file or class name and description of purpose be included on the
+ *       same "printed page" as the copyright notice for easier
+ *       identification within third-party archives.
+ *
+ *    Copyright 2016 Alibaba Group
+ *
+ *    Licensed under the Apache License, Version 2.0 (the "License");
+ *    you may not use this file except in compliance with the License.
+ *    You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *    Unless required by applicable law or agreed to in writing, software
+ *    distributed under the License is distributed on an "AS IS" BASIS,
+ *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *    See the License for the specific language governing permissions and
+ *    limitations under the License.
+ */
+package com.taobao.weex.ui.view.listview;
+
+import android.support.v7.widget.StaggeredGridLayoutManager;
+
+/**
+ * Created by zhengshihan on 2017/2/24.
+ */
+
+public class WXStaggeredGridLayoutManager extends StaggeredGridLayoutManager {
+    public WXStaggeredGridLayoutManager(int spanCount, int orientation) {
+        super(spanCount, orientation);
+        setGapStrategy(GAP_HANDLING_NONE);
+    }
+}
diff --git a/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java b/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
index 36d55c8..1345757 100644
--- a/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
+++ b/android/sdk/src/main/java/com/taobao/weex/ui/component/list/BasicListComponent.java
@@ -878,9 +878,14 @@ public abstract class BasicListComponent<T extends ViewGroup & ListComponentView
 
   }
 
+  protected void markComponentUsable(){
+    for (WXComponent component : mChildren){
+      component.setUsing(false);
+    }
+  }
   /**
    * Create an instance of {@link ListBaseViewHolder} for the given viewType (not for the given
    * index). This method will look up for the first component that fits the viewType requirement and
    * doesn't be used. Then create the certain type of view, detach the view f[rom the component.
    *
    * @param parent   the ViewGroup into which the new view will be inserted

http://git-wip-us.apache.org/repos/asf/incubator-weex/blob/c6db620e/android/sdk/src/main/java/com/taobao/weex/ui/component/list/WXListComponent.java
----------------------------------------------------------------------
@@ -878,9 +878,14 @@ public abstract class BasicListComponent<T extends ViewGroup & ListComponentView
   /**
    * Create an instance of {@link ListBaseViewHolder} for the given viewType (not for the given
-   * index). This method will look up for the first component that fits the viewType requirement and
+   * index). This  markComponentUsable();method will look up for the first component that fits the viewType requirement and
    * doesn't be used. Then create the certain type of view, detach the view f[rom the component.
    *